Contribute to pytest-dbfixtures
===============================

Thank you for taking time to contribute to pytest-dbfixtures!

The following is a set of guidelines for contributing to pytest-dbfixtures. These are just guidelines, not rules, use your best judgment and feel free to propose changes to this document in a pull request.

Bug Reports
-----------

#. Use a clear and descriptive title for the issue - it'll be much easier to identify the problem.
#. Describe the steps to reproduce the problems in as many details as possible.
#. If possible, provide a code snippet to reproduce the issue.

Feature requests/proposals
--------------------------

#. Use a clear and descriptive title for the proposal
#. Provide as detailed description as possible
    * Use case is great to have
#. There'll be a bit of discussion for the feature. Don't worry, if it is to be accepted, we'd like to support it, so we need to understand it thoroughly.
  

Pull requests
-------------

#. Start with a bug report or feature request
#. Use a clear and descriptive title
#. Provide a description - which issue does it refers to, and what part of the issue is being solved
#. Be ready for code review :)

Commits
-------

#. Make sure commits are atomic, and each atomic change is being followed by test.
#. If the commit solves part of the issue reported, include *refs #[Issue number]* in a commit message.
#. If the commit solves whole issue reported, please refer to `Closing issues via commit messages <https://help.github.com/articles/closing-issues-via-commit-messages/>`_ for ways to close issues when commits will be merged.


Coding style
------------

#. All python coding style are being enforced by `Pylama <https://pypi.python.org/pypi/pylama>`_ and configured in pylama.ini file.
#. Additional, not always mandatory checks are being performed by `QuantifiedCode <https://www.quantifiedcode.com/app/project/gh:ClearcodeHQ:pytest-dbfixtures>`_
